=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2006-06-28 20:18:53 +0000
+++ bzrlib/builtins.py	2006-06-29 16:30:47 +0000
@@ -2178,8 +2178,8 @@
             pending_merges = tree.pending_merges() 
             if len(pending_merges) != 1:
                 raise BzrCommandError("Sorry, remerge only works after normal"
-                                      + " merges.  Not cherrypicking or"
-                                      + "multi-merges.")
+                                      " merges.  Not cherrypicking or"
+                                      " multi-merges.")
             repository = tree.branch.repository
             base_revision = common_ancestor(tree.branch.last_revision(), 
                                             pending_merges[0], repository)

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2006-06-21 20:30:51 +0000
+++ bzrlib/tests/__init__.py	2006-06-29 16:30:47 +0000
@@ -739,6 +739,12 @@
             encoding = bzrlib.user_encoding
         return self.run_bzr(*args, **kwargs)[0].decode(encoding)
 
+    def run_bzr_error(self, error_regexes, *args, **kwargs):
+        """Run bzr, and check that stderr contains the supplied regexes"""
+        out, err = self.run_bzr(*args, **kwargs)
+        for regex in error_regexes:
+            self.assertContainsRe(err, regex)
+
     def run_bzr_subprocess(self, *args, **kwargs):
         """Run bzr in a subprocess for testing.
 

=== modified file 'bzrlib/tests/blackbox/__init__.py'
--- bzrlib/tests/blackbox/__init__.py	2006-06-20 03:30:14 +0000
+++ bzrlib/tests/blackbox/__init__.py	2006-06-29 16:30:47 +0000
@@ -68,6 +68,7 @@
                      'bzrlib.tests.blackbox.test_pull',
                      'bzrlib.tests.blackbox.test_push',
                      'bzrlib.tests.blackbox.test_reconcile',
+                     'bzrlib.tests.blackbox.test_remerge',
                      'bzrlib.tests.blackbox.test_remove',
                      'bzrlib.tests.blackbox.test_re_sign',
                      'bzrlib.tests.blackbox.test_revert',

=== added file 'bzrlib/tests/blackbox/test_remerge.py'
--- bzrlib/tests/blackbox/test_remerge.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/blackbox/test_remerge.py	2006-06-29 16:30:47 +0000
@@ -0,0 +1,106 @@
+# Copyright (C) 2005, 2006 by Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+
+import os
+
+from bzrlib.tests.blackbox import ExternalBase
+from bzrlib.workingtree import WorkingTree
+
+
+class TestRemerge(ExternalBase):
+
+    def make_file(self, name, contents):
+        f = open(name, 'wb')
+        f.write(contents)
+        f.close()
+
+    def create_conflicts(self):
+        """Create a conflicted tree"""
+        os.mkdir('base')
+        os.chdir('base')
+        self.make_file('hello', "hi world")
+        self.make_file('answer', "42")
+        self.run_bzr('init')
+        self.run_bzr('add')
+        self.run_bzr('commit', '-m', 'base')
+        self.run_bzr('branch', '.', '../other')
+        self.run_bzr('branch', '.', '../this')
+        os.chdir('../other')
+        self.make_file('hello', "Hello.")
+        self.make_file('answer', "Is anyone there?")
+        self.run_bzr('commit', '-m', 'other')
+        os.chdir('../this')
+        self.make_file('hello', "Hello, world")
+        self.run_bzr('mv', 'answer', 'question')
+        self.make_file('question', "What do you get when you multiply six"
+                                   "times nine?")
+        self.run_bzr('commit', '-m', 'this')
+
+    def test_remerge(self):
+        """Remerge command works as expected"""
+        self.create_conflicts()
+        self.run_bzr('merge', '../other', '--show-base', retcode=1)
+        conflict_text = open('hello').read()
+        self.assertTrue('|||||||' in conflict_text)
+        self.assertTrue('hi world' in conflict_text)
+
+        self.run_bzr('remerge', retcode=1)
+        conflict_text = open('hello').read()
+        self.assertFalse('|||||||' in conflict_text)
+        self.assertFalse('hi world' in conflict_text)
+
+        os.unlink('hello.OTHER')
+        os.unlink('question.OTHER')
+
+        self.run_bzr('remerge', 'jello', '--merge-type', 'weave', retcode=3)
+        self.run_bzr('remerge', 'hello', '--merge-type', 'weave', retcode=1)
+
+        self.failUnlessExists('hello.OTHER')
+        self.failIfExists('question.OTHER')
+
+        file_id = self.run_bzr('file-id', 'hello')[0]
+        self.run_bzr('file-id', 'hello.THIS', retcode=3)
+
+        self.run_bzr('remerge', '--merge-type', 'weave', retcode=1)
+
+        self.failUnlessExists('hello.OTHER')
+        self.failIfExists('hello.BASE')
+        self.assertFalse('|||||||' in conflict_text)
+        self.assertFalse('hi world' in conflict_text)
+
+        self.run_bzr_error(['Showing base is not supported.*Weave'],
+                           'remerge', '.', '--merge-type', 'weave', '--show-base',
+                           retcode=3)
+        self.run_bzr_error(['Can\'t reprocess and show base'],
+                           'remerge', '.', '--show-base', '--reprocess',
+                           retcode=3)
+        self.run_bzr_error(['conflicts encountered'],
+                           'remerge', '.', '--merge-type', 'weave', '--reprocess',
+                           retcode=1)
+        self.run_bzr_error(['conflicts encountered'],
+                           'remerge', 'hello', '--show-base',
+                           retcode=1)
+        self.run_bzr_error(['conflicts encountered'],
+                           'remerge', 'hello', '--reprocess', retcode=1)
+
+        self.run_bzr('resolve', '--all')
+        self.run_bzr('commit', '-m', 'done')
+
+        self.run_bzr_error(['remerge only works after normal merges',
+                            'Not cherrypicking or multi-merges'],
+                           'remerge',
+                           retcode=3)

=== modified file 'bzrlib/tests/blackbox/test_too_much.py'
--- bzrlib/tests/blackbox/test_too_much.py	2006-06-18 03:39:50 +0000
+++ bzrlib/tests/blackbox/test_too_much.py	2006-06-29 16:30:47 +0000
@@ -491,39 +491,6 @@
                                    "times nine?")
         self.runbzr('commit -m this')
 
-    def test_remerge(self):
-        """Remerge command works as expected"""
-        self.create_conflicts()
-        self.runbzr('merge ../other --show-base', retcode=1)
-        conflict_text = file('hello').read()
-        assert '|||||||' in conflict_text
-        assert 'hi world' in conflict_text
-        self.runbzr('remerge', retcode=1)
-        conflict_text = file('hello').read()
-        assert '|||||||' not in conflict_text
-        assert 'hi world' not in conflict_text
-        os.unlink('hello.OTHER')
-        os.unlink('question.OTHER')
-        self.runbzr('remerge jello --merge-type weave', retcode=3)
-        self.runbzr('remerge hello --merge-type weave', retcode=1)
-        assert os.path.exists('hello.OTHER')
-        self.assertIs(False, os.path.exists('question.OTHER'))
-        file_id = self.runbzr('file-id hello')
-        file_id = self.runbzr('file-id hello.THIS', retcode=3)
-        self.runbzr('remerge --merge-type weave', retcode=1)
-        assert os.path.exists('hello.OTHER')
-        assert not os.path.exists('hello.BASE')
-        assert '|||||||' not in conflict_text
-        assert 'hi world' not in conflict_text
-        self.runbzr('remerge . --merge-type weave --show-base', retcode=3)
-        self.runbzr('remerge . --show-base --reprocess', retcode=3)
-        self.runbzr('remerge . --merge-type weave --reprocess', retcode=1)
-        self.runbzr('remerge hello --show-base', retcode=1)
-        self.runbzr('remerge hello --reprocess', retcode=1)
-        self.runbzr('resolve --all')
-        self.runbzr('commit -m done',)
-        self.runbzr('remerge', retcode=3)
-
     def test_status(self):
         os.mkdir('branch1')
         os.chdir('branch1')

